@@ -9,10 +9,8 @@ import (
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/connectivity"
 
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry/resolver"
-	"github.com/operator-framework/operator-registry/pkg/api"
-	"github.com/operator-framework/operator-registry/pkg/api/grpc_health_v1"
-	"github.com/operator-framework/operator-registry/pkg/client"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -144,27 +142,30 @@ func (s *SourceStore) watch(ctx context.Context, key resolver.CatalogKey, source
 		case <-ctx.Done():
 			return
 		default:
-			timer, _ := context.WithTimeout(ctx, s.stateTimeout(state))
-			if source.Conn.WaitForStateChange(timer, state) {
-				newState := source.Conn.GetState()
-				state = newState
+			func() {
+				timer, cancel := context.WithTimeout(ctx, s.stateTimeout(state))
+				defer cancel()
+				if source.Conn.WaitForStateChange(timer, state) {
+					newState := source.Conn.GetState()
+					state = newState
 
-				// update connection state
-				src := s.Get(key)
-				if src == nil {
-					// source was removed, cleanup this goroutine
-					return
+					// update connection state
+					src := s.Get(key)
+					if src == nil {
+						// source was removed, cleanup this goroutine
+						return
+					}
+
+					src.LastConnect = metav1.Now()
+					src.ConnectionState = newState
+					s.sourcesLock.Lock()
+					s.sources[key] = *src
+					s.sourcesLock.Unlock()
+
+					// notify subscriber
+					s.notify <- SourceState{Key: key, State: newState}
 				}
-
-				src.LastConnect = metav1.Now()
-				src.ConnectionState = newState
-				s.sourcesLock.Lock()
-				s.sources[key] = *src
-				s.sourcesLock.Unlock()
-
-				// notify subscriber
-				s.notify <- SourceState{Key: key, State: newState}
-			}
+			}()
 		}
 	}
 }
@@ -189,9 +190,10 @@ func (s *SourceStore) Remove(key resolver.CatalogKey) error {
 	return source.Conn.Close()
 }
 
-func (s *SourceStore) AsClients(globalNamespace, localNamespace string) map[resolver.CatalogKey]client.Interface {
-	refs := map[resolver.CatalogKey]client.Interface{}
+func (s *SourceStore) AsClients(globalNamespace, localNamespace string) map[resolver.CatalogKey]registry.ClientInterface {
+	refs := map[resolver.CatalogKey]registry.ClientInterface{}
 	s.sourcesLock.RLock()
+	defer s.sourcesLock.RUnlock()
 	for key, source := range s.sources {
 		if !(key.Namespace == globalNamespace || key.Namespace == localNamespace) {
 			continue
@@ -199,19 +201,9 @@ func (s *SourceStore) AsClients(globalNamespace, localNamespace string) map[reso
 		if source.LastConnect.IsZero() {
 			continue
 		}
-		refs[key] = NewClient(source.Conn)
+		refs[key] = registry.NewClientFromConn(source.Conn)
 	}
-	s.sourcesLock.RUnlock()
 
 	// TODO : remove unhealthy
 	return refs
 }
-
-// TODO: move to operator-registry
-func NewClient(conn *grpc.ClientConn) client.Interface {
-	return &client.Client{
-		Registry: api.NewRegistryClient(conn),
-		Health:   grpc_health_v1.NewHealthClient(conn),
-		Conn:     conn,
-	}
-}
